@@ -1,5 +1,7 @@
 package Testing::Request::Find;
 
+use Scalar::Util 'blessed';
+
 use Test::Roo::Role;
 with 'Testing::Request';
 
@@ -40,5 +42,21 @@ test 'find request url by coord' => sub {
   cmp_ok $self->request_obj_bycoord->url, '=~', $re, 'by coord';
 };
 
+test 'find request by city code dies' => sub {
+  my ($self) = @_;
+  my $class = blessed $self->request_obj;
+  my $obj;
+  eval {;
+    $obj = $class->new(
+      api_key  => 'abcd',
+      location => 1234,
+    )
+  };
+  my $died = $@
+    or fail "Find request on city code did not throw exception";
+  isa_ok $died, 'Weather::OpenWeatherMap::Error';
+  like "$died", qr/city code/, 'Find request on city code dies ok';
+};
+
 
 1;
