@@ -25,7 +25,6 @@ test 'forecast request url by name' => sub {
             . $self->request_obj->_units
             . '&cnt='
             . $self->request_obj->days;
-  note $self->request_obj->url;
   cmp_ok $self->request_obj->url, '=~', $re, 'by name';
 };
 
@@ -37,7 +36,6 @@ test 'forecast request url by coord' => sub {
             . $self->request_obj_bycoord->_units
             . '&cnt='
             . $self->request_obj_bycoord->days;
-  note $self->request_obj_bycoord->url;
   cmp_ok $self->request_obj_bycoord->url, '=~', $re, 'by coord';
 };
 
@@ -49,7 +47,6 @@ test 'forecast request url by code' => sub {
             . $self->request_obj_bycode->_units
             . '&cnt='
             . $self->request_obj_bycode->days;
-  note $self->request_obj_bycode->url;
   cmp_ok $self->request_obj_bycode->url, '=~', $re, 'by code';
 };
 
